@@ -211,11 +211,11 @@ class anim_text:
 
         self.anim = anim
 
-        bpy.data.curves.new(type="FONT", name="Font Curve").body = "INIT"
-        font_obj = bpy.data.objects.new(name=name+'_text', object_data=bpy.data.curves["Font Curve"])
-        bpy.context.scene.collection.objects.link(font_obj)
+        bpy.ops.object.text_add()
+        ob=bpy.context.object
+        ob.data.body = "INIT"
 
-        self.obj = bpy.data.objects[name+'_text']
+        self.obj = ob
 
         self.obj.parent = parent
         self.name = name
@@ -223,7 +223,7 @@ class anim_text:
 
         if not(if_str):
             def update(self):
-                text = bpy.data.objects[name+'_text']
+                text = ob
                 cur_frame = bpy.context.scene.frame_current
                 
                 if np.any(cur_frame == anim.frames):
@@ -232,7 +232,7 @@ class anim_text:
                     
         else:
             def update(self):
-                text = bpy.data.objects[name+'_text']
+                text = ob
                 cur_frame = bpy.context.scene.frame_current
                 
                 if np.any(cur_frame == anim.frames):
